[openib-general] [PATCH] [IPoIB] Handle sending of unicast RARP responses

Hal Rosenstock halr at voltaire.com
Thu Jul 28 12:13:49 PDT 2005


[IPoIB] Handle sending of unicast RARP responses

Signed-off-by: Hal Rosenstock <halr at voltaire.com>

Any chance this can also make it to 2.6.13 ? Thanks.

-- Hal

Index: ipoib_main.c
===================================================================
--- ipoib_main.c	(revision 2929)
+++ ipoib_main.c	(working copy)
@@ -601,9 +601,10 @@ static int ipoib_start_xmit(struct sk_bu
 
 			ipoib_mcast_send(dev, (union ib_gid *) (phdr->hwaddr + 4), skb);
 		} else {
 			/* unicast GID -- should be ARP reply */
 
-			if (be16_to_cpup((__be16 *) skb->data) != ETH_P_ARP) {
+			if ((be16_to_cpup((__be16 *) skb->data) != ETH_P_ARP) &&
+			    (be16_to_cpup((__be16 *) skb->data) != ETH_P_RARP)) {
 				ipoib_warn(priv, "Unicast, no %s: type %04x, QPN %06x "
 					   IPOIB_GID_FMT "\n",
 					   skb->dst ? "neigh" : "dst",
@@ -601,9 +601,10 @@ static int ipoib_start_xmit(struct sk_bu
 			ipoib_mcast_send(dev, (union ib_gid *) (phdr->hwaddr + 4), skb);
 		} else {
-			/* unicast GID -- should be ARP reply */
+			/* unicast GID -- should be ARP or RARP reply */
 






More information about the general mailing list